@@ -3,10 +3,11 @@
 import appcli
 import autoprop
 import stepwise
+import freezerbox
 
 from inform import plural
-from ..group_by import group_by_synthesis, group_by_cleanup
-from ..model import load_maker_factory
+from freezerbox.group_by import group_by_synthesis, group_by_cleanup
+from freezerbox.model import load_maker_factory
 
 @autoprop
 class Make(appcli.App):
@@ -36,20 +37,20 @@ Arguments:
         products = [self.db[x] for x in self.tags]
 
         for key, group in group_by_synthesis(products):
-            for maker in iter_makers(key, group):
+            for maker in iter_makers(self.db, key, group):
                 protocol += maker.protocol
                 protocol += label_products(maker.products)
 
             parents = [x.parent for x in group]
             for key, subgroup in group_by_cleanup(parents):
-                for maker in iter_makers(key, subgroup):
+                for maker in iter_makers(self.db, key, subgroup):
                     protocol += maker.protocol
 
         return protocol
 
-def iter_makers(key, targets):
+def iter_makers(db, key, products):
     factory = load_maker_factory(key)
-    yield from factory(targets)
+    yield from factory(db, products)
 
 def label_products(products):
     tags = ', '.join(str(x.tag) for x in products)
@@ -57,7 +58,7 @@ def label_products(products):
 
 if __name__ == '__main__':
     app = Make.from_params()
-    app.db = load_db()
+    app.db = freezerbox.load_db()
     app.load()
     app.protocol.print()
 
